.. image:: https://travis-ci.org/Crowdlink/lever.png?branch=master   :target: https://travis-ci.org/Crowdlink/lever

============
Lever
============

Lever is a library for building REST APIs with Flask and SQLAlchemy. It is
similar in many ways to Sandman or Flask-Restless, but includes a robust ACL
system and rule based nested loading of objects.

**This software is v0, and as such isn't really designed or documented for easy
use unless you want to read through a lot of code.**

============
License
============

BSD
